@@ -46,6 +46,9 @@ def symbol_from_Z(z):
     return _z2symbol[z]
 
 
+ALL_ELEMENT_SYMBOLS = set(_pt_data.keys())
+
+
 @cached_class
 @total_ordering
 class Element(object):
@@ -419,10 +422,10 @@ class Element(object):
         return self._z
 
     def __repr__(self):
-        return "Element " + self._symbol
+        return "Element " + self.symbol
 
     def __str__(self):
-        return self._symbol
+        return self.symbol
 
     def __lt__(self, other):
         """
@@ -430,12 +433,12 @@ class Element(object):
         useful for getting correct formulas.  For example, FeO4PLi is
         automatically sorted into LiFePO4.
         """
-        if self._x != other._x:
-            return self._x < other._x
+        if self.X != other.X:
+            return self.X < other.X
         else:
             # There are cases where the electronegativity are exactly equal.
             # We then sort by symbol.
-            return self._symbol < other._symbol
+            return self.symbol < other.symbol
 
     @staticmethod
     def from_Z(z):
@@ -479,7 +482,7 @@ class Element(object):
             True if symbol is a valid element (e.g., "H"). False otherwise
             (e.g., "Zebra").
         """
-        return symbol in _pt_data
+        return symbol in ALL_ELEMENT_SYMBOLS
 
     @property
     def row(self):
@@ -580,7 +583,7 @@ class Element(object):
         """
         True if element is a metalloid.
         """
-        return self._symbol in ("B", "Si", "Ge", "As", "Sb", "Te", "Po")
+        return self.symbol in ("B", "Si", "Ge", "As", "Sb", "Te", "Po")
 
     @property
     def is_alkali(self):
@@ -643,7 +646,7 @@ class Element(object):
         """
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
-                "element": self._symbol}
+                "element": self.symbol}
 
 
 @cached_class
@@ -725,12 +728,12 @@ class Specie(MSONable):
         Sets a default sort order for atomic species by electronegativity,
         followed by oxidation state.
         """
-        if self._x != other._x:
-            return self._x < other._x
-        elif self._symbol != other._symbol:
+        if self.X != other.X:
+            return self.X < other.X
+        elif self.symbol != other.symbol:
             # There are cases where the electronegativity are exactly equal.
             # We then sort by symbol.
-            return self._symbol < other._symbol
+            return self.symbol < other.symbol
         else:
             other_oxi = 0 if isinstance(other, Element) else other.oxi_state
             return self.oxi_state < other_oxi
@@ -940,12 +943,12 @@ class DummySpecie(MSONable):
         Sets a default sort order for atomic species by electronegativity,
         followed by oxidation state.
         """
-        if self._x != other._x:
-            return self._x < other._x
-        elif self._symbol != other._symbol:
+        if self.X != other.X:
+            return self.X < other.X
+        elif self.symbol != other.symbol:
             # There are cases where the electronegativity are exactly equal.
             # We then sort by symbol.
-            return self._symbol < other._symbol
+            return self.symbol < other.symbol
         else:
             other_oxi = 0 if isinstance(other, Element) else other.oxi_state
             return self.oxi_state < other_oxi
@@ -976,7 +979,7 @@ class DummySpecie(MSONable):
         return self._symbol
 
     def __deepcopy__(self, memo):
-        return DummySpecie(self._symbol, self._oxi_state)
+        return DummySpecie(self.symbol, self._oxi_state)
 
     @staticmethod
     def from_string(species_string):
