@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 Module implementing an XYZ file object class.
 """
@@ -60,7 +58,7 @@ class XYZ(object):
         coords = []
         sp = []
         coord_patt = re.compile(
-            "(\w+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)"
+            "(\w+)\s+([0-9\-\.e]+)\s+([0-9\-\.e]+)\s+([0-9\-\.e]+)"
         )
         for i in xrange(2, 2 + num_sites):
             m = coord_patt.search(lines[i])
