@@ -32,14 +32,11 @@ def sort_dict(d, key=None, reverse=False):
     Sorts a dict by value.
 
     Args:
-        d:
-            Input dictionary
-        key:
-            function which takes an tuple (key, object) and returns a value to
+        d: Input dictionary
+        key: Function which takes an tuple (key, object) and returns a value to
             compare and sort by. By default, the function compares the values
             of the dict i.e. key = lambda t : t[1]
-        reverse:
-            allows to reverse sort order.
+        reverse: Allows to reverse sort order.
 
     Returns:
         OrderedDict object whose keys are ordered according to their value.
@@ -62,13 +59,15 @@ def chunks(items, n):
 
     >>> import pprint
     >>> pprint.pprint(list(chunks(range(1, 25), 10)))
-    [[1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
-     [11, 12, 13, 14, 15, 16, 17, 18, 19, 20],
-     [21, 22, 23, 24]]
+    [(1, 2, 3, 4, 5, 6, 7, 8, 9, 10),
+     (11, 12, 13, 14, 15, 16, 17, 18, 19, 20),
+     (21, 22, 23, 24)]
     """
-    for i in range(0, len(items), n):
-        yield items[i:i+n]
-
+    it = iter(items)
+    chunk = tuple(itertools.islice(it, n))
+    while chunk:
+        yield chunk
+        chunk = tuple(itertools.islice(it, n))
 
 def min_max_indexes(seq):
     """
@@ -141,14 +140,11 @@ def iuptri(items, diago=True, with_inds=False):
     A generator that yields the upper triangle of the matrix (items x items)
 
     Args:
-        items:
-            Iterable object with elements [e0, e1, ...]
-        diago:
-            False if diagonal matrix elements should be excluded
-        with_inds:
-            If True, (i,j) (e_i, e_j) is returned else (e_i, e_j)
+        items: Iterable object with elements [e0, e1, ...]
+        diago: False if diagonal matrix elements should be excluded
+        with_inds: If True, (i,j) (e_i, e_j) is returned else (e_i, e_j)
 
-    >>> for (ij, mate) in iuptri([0,1], with_inds=True): 
+    >>> for (ij, mate) in iuptri([0,1], with_inds=True):
     ...     print("ij:", ij, "mate:", mate)
     ij: (0, 0) mate: (0, 0)
     ij: (0, 1) mate: (0, 1)
@@ -169,14 +165,11 @@ def ilotri(items, diago=True, with_inds=False):
     A generator that yields the lower triangle of the matrix (items x items)
 
     Args:
-        items:
-            Iterable object with elements [e0, e1, ...]
-        diago:
-            False if diagonal matrix elements should be excluded
-        with_inds:
-            If True, (i,j) (e_i, e_j) is returned else (e_i, e_j)
+        items: Iterable object with elements [e0, e1, ...]
+        diago: False if diagonal matrix elements should be excluded
+        with_inds: If True, (i,j) (e_i, e_j) is returned else (e_i, e_j)
 
-    >>> for (ij, mate) in ilotri([0,1], with_inds=True): 
+    >>> for (ij, mate) in ilotri([0,1], with_inds=True):
     ...     print("ij:", ij, "mate:", mate)
     ij: (0, 0) mate: (0, 0)
     ij: (1, 0) mate: (1, 0)
@@ -190,3 +183,8 @@ def ilotri(items, diago=True, with_inds=False):
                     yield (ii, jj), (item1, item2)
                 else:
                     yield item1, item2
+
+
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
\ No newline at end of file
